package WebGUI::i18n::German::Asset_Event;
use utf8;
our $I18N = {
  'After' => {
    'lastUpdated' => '1257325541',
    'message' => 'Nach'
  },
  'By date' => {
    'lastUpdated' => '1257325551',
    'message' => 'Nach Datum'
  },
  'Daily' => {
    'lastUpdated' => '1257325557',
    'message' => 'Täglich'
  },
  'Every' => {
    'lastUpdated' => '1257325567',
    'message' => 'Jede(n)'
  },
  'Every N months on' => {
    'lastUpdated' => '1257325586',
    'message' => 'Jeden %s Monat am'
  },
  'Every N weeks on' => {
    'lastUpdated' => '1257325645',
    'message' => 'Jede %s Woche(n) am'
  },
  'Every N years on' => {
    'lastUpdated' => '1257325639',
    'message' => 'Jede %s Jahr(e) am'
  },
  'Monthly' => {
    'lastUpdated' => '1257325655',
    'message' => 'Monatlich'
  },
  'No end' => {
    'lastUpdated' => '1257325661',
    'message' => 'Ohne Ende'
  },
  'No specific time' => {
    'lastUpdated' => '1257325684',
    'message' => 'Keine Zeitangabe (ganztägig)'
  },
  'Specific start/end time' => {
    'lastUpdated' => '1257325706',
    'message' => 'Konkreter Start-/End-Zeitpunkt'
  },
  'The event end date must be after the event start date.' => {
    'lastUpdated' => '1247818673',
    'message' => 'Das End-Datum muss nach dem Anfangsdatum liegen.'
  },
  'The event end time must be after the event start time.' => {
    'lastUpdated' => '1247818665',
    'message' => 'Die Ende-Uhrzeit muss nach der Anfangsuhrzeit liegen.'
  },
  'UserDefinedN' => {
    'lastUpdated' => '1180079545',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder der Wert dieses Feldes.'
  },
  'Weekday(s)' => {
    'lastUpdated' => '1257325715',
    'message' => 'Werktags'
  },
  'Weekly' => {
    'lastUpdated' => '1257325722',
    'message' => 'Wöchentlich'
  },
  'Yearly' => {
    'lastUpdated' => '1257325728',
    'message' => 'Jährlich'
  },
  'add related link' => {
    'lastUpdated' => '1221215688',
    'message' => 'Verwandter Link hinzufügen'
  },
  'add/edit title' => {
    'lastUpdated' => '1180079622',
    'message' => 'Termin hinzufüge/bearbeiten'
  },
  'assetName' => {
    'lastUpdated' => '1157932400',
    'message' => 'Termin'
  },
  'attachment.icon' => {
    'lastUpdated' => '1193130493',
    'message' => 'Ein Ikon, das den Dateityp des Anhangs zeigt.'
  },
  'attachment.name' => {
    'lastUpdated' => '1193130599',
    'message' => 'Der Name der ersten anghängten Datei.

'
  },
  'attachment.url' => {
    'lastUpdated' => '1193130625',
    'message' => 'Die URL, um die erste angehängte Datei herunterzuladen.'
  },
  'attachment_loop' => {
    'lastUpdated' => '1193130678',
    'message' => 'Eine Schleife, die alle angehängten Dateien und Bilder enthält.'
  },
  'attachment_url' => {
    'lastUpdated' => '1193130735',
    'message' => 'Die URL um den Anhang herunterzuladen.'
  },
  'attachments' => {
    'lastUpdated' => '1212757547',
    'message' => 'Anhänge'
  },
  'attachments for event' => {
    'lastUpdated' => '1212757560',
    'message' => 'Anhänge für diesen Termin'
  },
  'canEdit' => {
    'lastUpdated' => '1193130762',
    'message' => 'Diese Variable ist wahr, wenn der gegenwärtige Benutzer dieses Ereignis editieren kann.'
  },
  'dateSpan' => {
    'lastUpdated' => '1180079667',
    'message' => 'Anzeige der Start und End Daten und Zeiten.'
  },
  'day' => {
    'lastUpdated' => '1257325733',
    'message' => 'Tag'
  },
  'delete' => {
    'lastUpdated' => '1212757226',
    'message' => 'Löschen'
  },
  'description' => {
    'lastUpdated' => '1180079679',
    'message' => 'Beschreibung dieses Termins.'
  },
  'description label' => {
    'lastUpdated' => '1217254610',
    'message' => 'Beschreibung'
  },
  'edit' => {
    'lastUpdated' => '1212757507',
    'message' => 'Bearbeiten'
  },
  'end' => {
    'lastUpdated' => '1212757519',
    'message' => 'Ende'
  },
  'end date' => {
    'lastUpdated' => '1217254622',
    'message' => 'Enddatum'
  },
  'endDate' => {
    'lastUpdated' => '1180079689',
    'message' => 'Datum, an dem dieser Termin endet.'
  },
  'endDateDayAbbr' => {
    'lastUpdated' => '1181941042',
    'message' => 'A'
  },
  'endDateDayName' => {
    'lastUpdated' => '1180079931',
    'message' => 'Der Name des Tages, an dem dieser Termin endet.'
  },
  'endDateDayOfMonth' => {
    'lastUpdated' => '1180079957',
    'message' => 'Der Tag des Monats, an dem dieser Termin endet, Zahl von 1 bis 31.'
  },
  'endDateDayOfWeek' => {
    'lastUpdated' => '1180079980',
    'message' => 'Der Tag der Woche, an dem dieser Termin endet, Zahl von 1 bis 7.'
  },
  'endDateDmy' => {
    'lastUpdated' => '1180080046',
    'message' => 'Enddatum dieses Termins im dd-mm-yyyy Format. yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  },
  'endDateEpoch' => {
    'lastUpdated' => '1180080075',
    'message' => 'Enddatum und Endzeit dieses Termins, im "epoch" Format.'
  },
  'endDateHms' => {
    'lastUpdated' => '1180080106',
    'message' => 'Endzeit dieses Termins im hh:mm:ss Format. hh -> Stunde, mm -> Minute, ss -> Sekunde.'
  },
  'endDateHour' => {
    'lastUpdated' => '1180080122',
    'message' => 'Stunde, zu der dieser Termin endet.'
  },
  'endDateHour24' => {
    'lastUpdated' => '1180080153',
    'message' => 'Die Stunde, zu der dieser Termin endet (24 Stunden Anzeige).'
  },
  'endDateHourM' => {
    'lastUpdated' => '1180080186',
    'message' => 'Je nachdem, ob der Termin morgens oder nachmittags endet; String "am" oder "pm".'
  },
  'endDateMdy' => {
    'lastUpdated' => '1180080218',
    'message' => 'Enddatum dieses Termins im mm-dd-yyyy Format; yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  },
  'endDateMinute' => {
    'lastUpdated' => '1180080288',
    'message' => 'Minute, zu der dieser Termin endet; zwei Ziffern, führende 0.'
  },
  'endDateMonthAbbr' => {
    'lastUpdated' => '1180079732',
    'message' => 'Abkürzung des Namens des Monats, an dem dieser Termin endet.'
  },
  'endDateMonthName' => {
    'lastUpdated' => '1180080308',
    'message' => 'Der Name des Monats, an dem dieser Termin endet.'
  },
  'endDateSecond' => {
    'lastUpdated' => '1180080342',
    'message' => 'Sekunde, zu der dieser Termin endet; zwei Ziffern, führende 0.'
  },
  'endDateYear' => {
    'lastUpdated' => '1180080370',
    'message' => 'Das Jahr, in dem der Termin endet; 4 Ziffern.'
  },
  'endDateYmd' => {
    'lastUpdated' => '1180080401',
    'message' => 'Das Enddatum dieses Termins im yyyy-mm-dd Format; yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  },
  'endTime' => {
    'lastUpdated' => '1180080413',
    'message' => 'Enddatum dieses Termins.'
  },
  'errors' => {
    'lastUpdated' => '1212757235',
    'message' => 'Fehler!'
  },
  'event asset template variables body' => {
    'lastUpdated' => '1180082505',
    'message' => 'Jedes Asset bietet für die meisten seiner Templates einen Satz an Variablen, basierend auf den internen Asset Eigenschaften. Einige dieser Variablen können n&uuml;tzlich sein, andere nicht.'
  },
  'event asset template variables title' => {
    'lastUpdated' => '1180082434',
    'message' => 'Termin Asset Template Variablen'
  },
  'event common template variables body' => {
    'lastUpdated' => '1180082418',
    'message' => 'Diese Template Variablen werden vom Termin und vom Kalender benutzt.'
  },
  'event common template variables title' => {
    'lastUpdated' => '1180082396',
    'message' => 'Termin gebrächliche Template Variablen'
  },
  'event details' => {
    'lastUpdated' => '1212757247',
    'message' => 'Termindetails'
  },
  'event title' => {
    'lastUpdated' => '1212757267',
    'message' => 'Termintitel'
  },
  'event view template variables body' => {
    'lastUpdated' => '1180082377',
    'message' => 'Diese Template Variablen werden vom Template benutzt, das diesen Termin dem Benutzer präsentiert.'
  },
  'event view template variables title' => {
    'lastUpdated' => '1180082348',
    'message' => 'Termin Ansicht Template Variablen'
  },
  'exclude dates' => {
    'lastUpdated' => '1212757280',
    'message' => 'Datum ausschliessen'
  },
  'feedId' => {
    'lastUpdated' => '1180082335',
    'message' => 'Der eindeutige Bezeichner für einen iCal Feed.'
  },
  'feedUid' => {
    'lastUpdated' => '1180082315',
    'message' => 'Der Ort, an dem der Termin stattfindet.'
  },
  'filename' => {
    'lastUpdated' => '1192789489',
    'message' => 'Dateiname'
  },
  'first' => {
    'lastUpdated' => '1257325748',
    'message' => 'Erste(r)'
  },
  'formAttachments' => {
    'lastUpdated' => '1193130822',
    'message' => 'HTML-Formular, um Dateien von diesem Ereignis hinzuzufügen oder zu löschen.'
  },
  'formCancel' => {
    'lastUpdated' => '1180082301',
    'message' => 'HTML für eine Schaltfläche f&uuml;r den Abbruch, das Hinzuf&uuml;gen oder Bearbeiten eines Termins.'
  },
  'formDescription' => {
    'lastUpdated' => '1180082254',
    'message' => 'HTML Formular für die Eingabe oder Bearbeitung der Terminbeschreibung.'
  },
  'formEndDate' => {
    'lastUpdated' => '1180082224',
    'message' => 'HTML Formular für die Eingabe oder Bearbeitung des Enddatums des Termins.'
  },
  'formEndTime' => {
    'lastUpdated' => '1180082203',
    'message' => 'HTML Formular für die Eingabe und Bearbeitung der Endzeit des Termins.'
  },
  'formErrors' => {
    'lastUpdated' => '1180082177',
    'message' => 'Diese Schleife enthält jeden Fehler, der beim Bearbeiten von Termin Formulardaten aufgetreten ist.'
  },
  'formFooter' => {
    'lastUpdated' => '1180082144',
    'message' => 'HTML für das Ende des Hinzuf&uuml;gen/Bearbeiten Formulars.'
  },
  'formGroupToView' => {
    'lastUpdated' => '1193130876',
    'message' => 'HTML-Formular, um zu erkennen welche Gruppe dieses Ereignis ansehen kann.'
  },
  'formHeader' => {
    'lastUpdated' => '1180082124',
    'message' => 'HTML und Javascript für den Start des Hinzuf&uuml;gen/Bearbeiten Formulars.'
  },
  'formLocation' => {
    'lastUpdated' => '1180082093',
    'message' => 'HTML Formular für die Eingabe oder Bearbeitung eines Orts, an dem der Termin stattfinden soll.'
  },
  'formMenuTitle' => {
    'lastUpdated' => '1180082058',
    'message' => 'HTML Formular für die Eingabe oder Bearbeitung des Men&uuml;titels eines Termins.'
  },
  'formRecurEnd' => {
    'lastUpdated' => '1180082018',
    'message' => 'HTML Datumsformular für die Eingabe, wann ein sich wiederholender Termin enden soll, falls er &uuml;berhaupt enden soll.'
  },
  'formRecurPattern' => {
    'lastUpdated' => '1180081974',
    'message' => 'HTML und Javascript für ein Formular, das definiert, wie sich ein Termin wiederholen soll.'
  },
  'formRecurStart' => {
    'lastUpdated' => '1180081936',
    'message' => 'HTML Datumsformular für die Eingabe des ersten Datums, an dem sich ein Termin wiederholen soll.'
  },
  'formRelatedLinks' => {
    'lastUpdated' => '1180082620',
    'message' => 'Ein HTML Text Formular für die Eingabe von URLs zu Webseiten, die weitere n&uuml;tzliche Informationen &uuml;ber diesen Termin bereithalten. Individuelle Links sollten Zeile f&uuml;r Zeile hinzugef&uuml;gt werden.'
  },
  'formSave' => {
    'lastUpdated' => '1180081448',
    'message' => 'HTML Code für eine Schaltfläche, um Termindaten zu speichern.'
  },
  'formStartDate' => {
    'lastUpdated' => '1180081419',
    'message' => 'HTML Formular für die Eingabe des Startdatums des Termins.'
  },
  'formStartTime' => {
    'lastUpdated' => '1180081391',
    'message' => 'HTML Formular für die Eingabe der Startzeit des Termins.'
  },
  'formSynopsis' => {
    'lastUpdated' => '1257325779',
    'message' => 'HTML-Formular um die Event-Zusammenfassung einzugeben oder zu bearbeiten'
  },
  'formTime' => {
    'lastUpdated' => '1180081371',
    'message' => 'Ein HTML Formular, um die Start- und Endzeit des Termins einzutragen. Das Formular besitzt Vorbelegungen für den  ganzen Tag, keine bestimmte Zeit oder eine bestimmte Start- und Endzeit.'
  },
  'formTitle' => {
    'lastUpdated' => '1180081260',
    'message' => 'HTML Formular für die Eingabe des Termintitels.'
  },
  'formUserDefinedN' => {
    'lastUpdated' => '1199975116',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular f&uuml;r eine einzige Zeile Text.'
  },
  'formUserDefinedN_float' => {
    'lastUpdated' => '1199975137',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular f&uuml;r eine einen Float (Gleitkommazahl).'
  },
  'formUserDefinedN_htmlarea' => {
    'lastUpdated' => '1199975165',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular f&uuml;r ein WYSIWYG HTML Bereich.'
  },
  'formUserDefinedN_textarea' => {
    'lastUpdated' => '1199975181',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular f&uuml;r einen Textbereich.'
  },
  'formUserDefinedN_yesNo' => {
    'lastUpdated' => '1199975195',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular f&uuml;r ein Ja/Nein Feld.'
  },
  'fourth' => {
    'lastUpdated' => '1257325790',
    'message' => 'Vierter'
  },
  'group to view' => {
    'lastUpdated' => '1212757297',
    'message' => 'Gruppe anzeigen'
  },
  'groupToView' => {
    'lastUpdated' => '1180081241',
    'message' => 'Die ID der Gruppe, die diesen Termin anschauen darf.'
  },
  'icon' => {
    'lastUpdated' => '1193131816',
    'message' => 'Das Ikon, das die Dateiart dieser angehängten Datei anzeigt.'
  },
  'image.thumbnail' => {
    'lastUpdated' => '1199975030',
    'message' => 'Ein Vorschaubild (Thumbnail) eines Bildes, das dem Post als Anhang angefügt ist.'
  },
  'image.url' => {
    'lastUpdated' => '1193131860',
    'message' => 'Die URL zum ersten angehängten Bild.'
  },
  'include dates' => {
    'lastUpdated' => '1212757322',
    'message' => 'Datum einbinden'
  },
  'invalid end date' => {
    'lastUpdated' => '1295596884',
    'message' => 'Ungültige Datumsangabe für Endzeitpunkt, bitte geben Sie ein gültiges Datum im Format JJJJJ-MM-TT ein.'
  },
  'invalid start date' => {
    'lastUpdated' => '1295596900',
    'message' => 'Ungültige Datumsangabe für Startzeitpunkt, bitte geben Sie ein gültiges Datum im Format JJJJJ-MM-TT ein.'
  },
  'isAllDay' => {
    'lastUpdated' => '1180081225',
    'message' => 'Bedingung, die wahr ist, falls der Termin den ganzen Tag in Anspruch nimmt.'
  },
  'isImage' => {
    'lastUpdated' => '1193131773',
    'message' => 'Ein bedingtes Anzeigen, wenn die angehängte Datei ein Bild ist.'
  },
  'isOneDay' => {
    'lastUpdated' => '1180081202',
    'message' => 'Bedingung, die wahr ist, falls der Termin am gleichen Tag beginnt und endet.'
  },
  'isPublic' => {
    'lastUpdated' => '1180081177',
    'message' => 'Bedingung, die wahr ist, falls die Gruppe, die den Termin anschauen darf, die Gruppe Everyone ist.'
  },
  'last' => {
    'lastUpdated' => '1257325796',
    'message' => 'Letzter'
  },
  'link description' => {
    'lastUpdated' => '1217254632',
    'message' => 'Link Beschreibung'
  },
  'link view group' => {
    'lastUpdated' => '1212757465',
    'message' => 'Zeige Gruppe'
  },
  'linkUrl' => {
    'lastUpdated' => '1180082669',
    'message' => 'Eine URL aus dem Satz der "related" Links.'
  },
  'locale' => {
    'lastUpdated' => '1180081131',
    'message' => 'de_DE'
  },
  'location' => {
    'lastUpdated' => '1212757482',
    'message' => 'Ort'
  },
  'message' => {
    'lastUpdated' => '1180081085',
    'message' => 'Eine Fehlermeldung.'
  },
  'next event' => {
    'lastUpdated' => '1212757332',
    'message' => 'Nächster Termin'
  },
  'nextUrl' => {
    'lastUpdated' => '1180081062',
    'message' => 'URL, um zum nächsten Termin des Kalenders zu gelangen.'
  },
  'occurences' => {
    'lastUpdated' => '1257325833',
    'message' => 'Auftreten'
  },
  'of' => {
    'lastUpdated' => '1257325838',
    'message' => 'von'
  },
  'prevUrl' => {
    'lastUpdated' => '1180081072',
    'message' => 'URL, um zum vorherigen Termin des Kalenders zu gelangen.'
  },
  'previous event' => {
    'lastUpdated' => '1212757448',
    'message' => 'vorheriger Termin'
  },
  'print' => {
    'lastUpdated' => '1212757394',
    'message' => 'drucken'
  },
  'recurId' => {
    'lastUpdated' => '1180081011',
    'message' => 'Eindeutiger Bezeichner für die Wiederholung dieses Termins in der Datenbank.'
  },
  'recurrence' => {
    'lastUpdated' => '1217254653',
    'message' => 'Wiederholung'
  },
  'recurrence pattern' => {
    'lastUpdated' => '1221215788',
    'message' => 'Wiederholungsschema'
  },
  'recurrence range' => {
    'lastUpdated' => '1221215836',
    'message' => 'Wiederholungsbereich'
  },
  'related material' => {
    'lastUpdated' => '1212757419',
    'message' => 'zugehöriges Material'
  },
  'relatedLinks' => {
    'lastUpdated' => '1180082699',
    'message' => 'Diese Schleife enthält alle Links von dem Satz der "related" Links dieses Termins.'
  },
  'relatedLinks assetVar' => {
    'lastUpdated' => '1180082747',
    'message' => 'Die originalen, nicht verarbeiteten "related" Links vom Formular. Dies sind alle Links in einem String.'
  },
  'scheduled' => {
    'lastUpdated' => '1238534533',
    'message' => 'Terminiert'
  },
  'second' => {
    'lastUpdated' => '1257325846',
    'message' => 'zweite(r)'
  },
  'short title' => {
    'lastUpdated' => '1212757368',
    'message' => 'Kurztitel'
  },
  'start' => {
    'lastUpdated' => '1212757342',
    'message' => 'Start'
  },
  'start date' => {
    'lastUpdated' => '1212757358',
    'message' => 'Starttermin'
  },
  'startDate' => {
    'lastUpdated' => '1180080936',
    'message' => 'Das Startdatum dieses Termins.'
  },
  'startDateDayAbbr' => {
    'lastUpdated' => '1180079753',
    'message' => 'Abkürzung des Namens des Tages, an dem dieser Termin beginnt.'
  },
  'startDateDayName' => {
    'lastUpdated' => '1180080920',
    'message' => 'Der Name des Tages, an dem dieser Termin startet.'
  },
  'startDateDayOfMonth' => {
    'lastUpdated' => '1180080902',
    'message' => 'Der Tag des Monats, an dem dieser Termin startet; Zahl zwischen 1 und 31.'
  },
  'startDateDayOfWeek' => {
    'lastUpdated' => '1180080876',
    'message' => 'Der Tag der Woche, zu der dieser Termin startet; Zahl zwischen 1 und 7.'
  },
  'startDateDmy' => {
    'lastUpdated' => '1180080849',
    'message' => 'Das Startdatum dieses Termins im dd-mm-yyyy Format; yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  },
  'startDateEpoch' => {
    'lastUpdated' => '1180080815',
    'message' => 'Startdatum dieses Termins, im "epoch" Format.'
  },
  'startDateHms' => {
    'lastUpdated' => '1180080796',
    'message' => 'Die Startzeit dieses Termins im hh:mm:ss Format; hh -> Stunde, mm -> Minute, ss -> Sekunde.'
  },
  'startDateHour' => {
    'lastUpdated' => '1180080764',
    'message' => 'Die Stunde, zu der dieser Termin startet.'
  },
  'startDateHour24' => {
    'lastUpdated' => '1180080750',
    'message' => 'Die Stunde, zu der dieser Termin beginnt (24 Stunden Anzeige).'
  },
  'startDateHourM' => {
    'lastUpdated' => '1180080727',
    'message' => 'Abhängig davon, ob der Termin morgens oder nachmittags ist, der String "am" oder "pm".'
  },
  'startDateMdy' => {
    'lastUpdated' => '1180080676',
    'message' => 'Startdatum dieses Events im mm-dd-yyyy Format; yyyy -> Jahr, dd -> Monat, mm -> Tag.'
  },
  'startDateMinute' => {
    'lastUpdated' => '1180080562',
    'message' => 'Minute, zu der dieser Termin startet; zwei Ziffern, führende 0.'
  },
  'startDateMonthAbbr' => {
    'lastUpdated' => '1180079769',
    'message' => 'Abkürzung des Namens des Monats, an dem dieser Termin beginnt.'
  },
  'startDateMonthName' => {
    'lastUpdated' => '1180080527',
    'message' => 'Der Name des Monats, in dem dieser Termin startet.'
  },
  'startDateSecond' => {
    'lastUpdated' => '1180080549',
    'message' => 'Sekunde, zu der dieser Termin startet; zwei Ziffern, führende 0.'
  },
  'startDateYear' => {
    'lastUpdated' => '1180080582',
    'message' => 'Das Jahr, in dem dieser Termin startet; 4 Ziffern.'
  },
  'startDateYmd' => {
    'lastUpdated' => '1180080610',
    'message' => 'Startdatum dieses Termins im yyyy-mm-dd Format; yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  },
  'startTime' => {
    'lastUpdated' => '1180080624',
    'message' => 'Das Datum, an dem dieser Termin startet.'
  },
  'tab event' => {
    'lastUpdated' => '1217254684',
    'message' => 'Termin'
  },
  'third' => {
    'lastUpdated' => '1257325858',
    'message' => 'dritte(r)'
  },
  'thumbnail' => {
    'lastUpdated' => '1193130921',
    'message' => 'Ein Thumbnail dieses Anhangs, wenn möglich.'
  },
  'time' => {
    'lastUpdated' => '1212757349',
    'message' => 'Zeit'
  },
  'url' => {
    'lastUpdated' => '1180080504',
    'message' => 'URL dieses Termins.'
  },
  'urlDay' => {
    'lastUpdated' => '1180080494',
    'message' => 'URL, um alle Termine am gleichen Tag in diesem Kalender anzuzeigen.'
  },
  'urlDelete' => {
    'lastUpdated' => '1241154303',
    'message' => 'Eine URL um diesen Termin zu löschen.'
  },
  'urlEdit' => {
    'lastUpdated' => '1241154324',
    'message' => 'URL um diesen Termin zu ändern.'
  },
  'urlList' => {
    'lastUpdated' => '1241154348',
    'message' => 'URL um die Termine als Liste anzuzeigen.'
  },
  'urlMonth' => {
    'lastUpdated' => '1180080470',
    'message' => 'URL, um alle Termine im gleichen Monat dieses Kalenders anzuzeigen.'
  },
  'urlParent' => {
    'lastUpdated' => '1241154258',
    'message' => 'URL zum Kalender, der diesen Termin enthält.'
  },
  'urlPrint' => {
    'lastUpdated' => '1241154250',
    'message' => 'Eine URL um diesen Termin unter Verwending seiner Vorlage für den Ausdruck vorzubereiten.'
  },
  'urlSearch' => {
    'lastUpdated' => '1180079918',
    'message' => 'URL zu einem Such Formular des Kalenders, der diesen Termin enthält.'
  },
  'urlWeek' => {
    'lastUpdated' => '1180079886',
    'message' => 'URL, um alle Termine derselben Woche in diesem Kalender anzuzeigen.'
  },
  'week on' => {
    'lastUpdated' => '1257325878',
    'message' => 'Woche im'
  }
}
;

1;
